@@ -377,9 +377,9 @@ class GSPeerConnectionBroadcasterPiSocketv2:
                 offer = await pc.createOffer()
                 await pc.setLocalDescription(offer)
 
-            loop = asyncio.get_event_loop()
+
             # loop.run_until_complete( pc.setLocalDescription(awaitpc.createOffer()))
-            loop.run_until_complete(create_and_set_local_description(pc))
+            asyncio.run(create_and_set_local_description(pc))
 
 
             self.sio.emit("watcher", {"target": description,
@@ -397,15 +397,14 @@ class GSPeerConnectionBroadcasterPiSocketv2:
                         description = ast.literal_eval(description)
                     desc = type('new_dict', (object,), description)
                     answer = RTCSessionDescription(sdp=description["sdp"], type=description["type"])
-                    loop = asyncio.get_event_loop()
-                    loop.run_until_complete(self.peerConnections[id].setRemoteDescription(answer))
+
+                    asyncio.run(self.peerConnections[id].setRemoteDescription(answer))
 
         @self.sio.event
         def disconnectBroadcaster(id, desc):
             if id in self.peerConnections:
                 self._logger.info("Disconnected Peer")
-                loop = asyncio.get_event_loop()
-                loop.run_until_complete(self.peerConnections[id].close())
+                asyncio.run(self.peerConnections[id].close())
                 self.peerConnections.pop(id, None)
 
         @self.sio.event
